@@ -93,7 +93,7 @@ PROBLEM_LAYERS = {
             "collision_camera_063",  # Kraid arena
         ],
         "s040_aqua": [
-            "collision_camera_004",  # Below Drogyga
+            "collision_camera_007",  # Below Drogyga
             "collision_camera_028",  # Drogyga arena
         ],
         "s070_basesanc": [
@@ -102,7 +102,12 @@ PROBLEM_LAYERS = {
     },
     "Cooldown": {
         "s020_magma": [
-            "collision_camera_004",
+            "collision_camera_004", # Z-57 Access
+        ]
+    },
+    "PostEmmy": {
+        "s070_basesanc": [
+            "collision_camera_040", # Purple Emmi Introduction
         ]
     }
 }
@@ -128,13 +133,14 @@ def _apply_boss_cutscene_fixes(editor: PatcherEditor, cutscene_ref: dict, callba
     cutscene_player.pComponents.CUTSCENE.vctOnAfterCutsceneEndsLA.pop()
 
     # Add the custom call when the boss dies
-    cutscene_player.pComponents.CUTSCENE.vctOnAfterCutsceneEndsLA.append({
-        "@type": "CLuaCallsLogicAction",
-        "sCallbackEntityName": "",
-        "sCallback": callback,
-        "bCallbackEntity": False,
-        "bCallbackPersistent": False,
-    })
+    if callback:
+        cutscene_player.pComponents.CUTSCENE.vctOnAfterCutsceneEndsLA.append({
+            "@type": "CLuaCallsLogicAction",
+            "sCallbackEntityName": "",
+            "sCallback": callback,
+            "bCallbackEntity": False,
+            "bCallbackPersistent": False,
+        })
 
 def apply_kraid_fixes(editor: PatcherEditor):
     magma = editor.get_scenario("s020_magma")
@@ -155,6 +161,17 @@ def apply_kraid_fixes(editor: PatcherEditor):
     kraid.pComponents.AI.wpDeadCheckpointStartPoint = "{EMPTY}"
     kraid_file.InnerValue = CActor.build(kraid)
 
+def apply_drogyga_fixes(editor: PatcherEditor):
+    _apply_boss_cutscene_fixes(editor, {
+        "scenario": "s040_aqua",
+        "layer": "cutscenes",
+        "actor": "cutsceneplayer_65"
+    }, "CurrentScenario.OnHydrogigaDead_CUSTOM")
+
+    # remove the trigger that deletes drogyga until after beating drogyga
+    aqua = editor.get_scenario("s040_aqua")
+    aqua.remove_actor_from_group("eg_collision_camera_007_Default", "TG_WaterPoolAfterHydrogiga", "Boss")
+
 def activate_emmi_zones(editor: PatcherEditor):
     # Remove the cutscene that plays when you enter the emmi zone for the first time
     # This causes the border of the zone to not be revealed, but it should be possible to do that in another way
@@ -278,6 +295,12 @@ def patch_corpius_checkpoints(editor: PatcherEditor):
 def apply_experiment_fixes(editor: PatcherEditor):
     magma = editor.get_scenario("s020_magma")
 
+    _apply_boss_cutscene_fixes(editor, {
+        "scenario": "s020_magma",
+        "layer": "cutscenes",
+        "actor": "cutsceneplayer_81"
+    }, "")
+
     new_triggers = {
         "TriggerEnableCooldown": (5050.000, -5346.150, 0.000),
         "TriggerDisableCooldown": (5000.000, -7350.000, 0.000),
@@ -329,3 +352,4 @@ def apply_static_fixes(editor: PatcherEditor):
     fix_backdoor_white_cu(editor)
     patch_corpius_checkpoints(editor)
     apply_experiment_fixes(editor)
+    apply_drogyga_fixes(editor)
